# generated by datamodel-codegen:
#   filename:  process_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from datetime import date, datetime
from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, constr, Extra, Field

from . import (comment_schema,
               data_schema,
               material_schema,
               process_parameter_value_schema,
               protocol_schema,
               sample_schema,
               source_schema)


class FieldType(Enum):
    Process = 'Process'


class IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles(
        BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    name: Optional[str] = None
    executesProtocol: Optional[protocol_schema.IsaProtocolSchema] = None
    parameterValues: Optional[List[
        process_parameter_value_schema.IsaProcessParameterValueSchema]] = None
    performer: Optional[str] = None
    date: Optional[Union[datetime, date, constr(max_length=0)]] = None
    previousProcess: Optional[
        IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles] = None
    nextProcess: Optional[
        IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles] = None
    inputs: Optional[List[Union[source_schema.IsaSourceSchema,
                                sample_schema.IsaSampleSchema,
                                data_schema.IsaDataSchema,
                                material_schema.IsaMaterialSchema,]]] = None
    outputs: Optional[List[Union[sample_schema.IsaSampleSchema,
                                 data_schema.IsaDataSchema,
                                 material_schema.IsaMaterialSchema,]]] = None
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None


IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles.update_forward_refs(
)



# generated by datamodel-codegen:
#   filename:  study_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from datetime import date, datetime
from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, constr, Extra, Field

from . import (
    assay_schema,
    comment_schema,
    factor_schema,
    material_attribute_schema,
    material_schema,
    ontology_annotation_schema,
    person_schema,
    process_schema,
    protocol_schema,
    publication_schema,
    sample_schema,
    source_schema,
)


class FieldType(Enum):
    Study = 'Study'


class ISAStudyJSONSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    filename: Optional[str] = None
    identifier: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None
    submissionDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    publicReleaseDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    publications: Optional[List[publication_schema.ISAPublicationSchema]] = None
    people: Optional[List[person_schema.ISAPersonSchema]] = None
    studyDesignDescriptors: Optional[List[
        ontology_annotation_schema.ISAOntologyReferenceSchema]] = None
    protocols: Optional[List[protocol_schema.ISAProtocolSchema]] = None
    materials: Optional[Materials] = None
    processSequence: Optional[List[
        process_schema.
        ISAProcessOrProtocolApplicationSchemaCorrespondsToProtocolREFColumnsInTheStudyAndAssayFiles]] = None
    assays: Optional[List[assay_schema.ISAAssayJSONSchema]] = None
    factors: Optional[List[factor_schema.ISAFactorSchema]] = None
    characteristicCategories: Optional[List[
        material_attribute_schema.ISAMaterialAttributeSchema]] = Field(
            None,
            description=
            'List of all the characteristics categories (or material attributes) defined in the study, used to avoid duplication of their declaration when each material_attribute_value is created. ',
        )
    unitCategories: Optional[List[ontology_annotation_schema.ISAOntologyReferenceSchema]] = Field(
        None,
        description=
        'List of all the units defined in the study, used to avoid duplication of their declaration when each value is created. ',
    )
    comments: Optional[List[comment_schema.ISACommentSchema]] = None


class Materials(BaseModel):
    sources: Optional[List[source_schema.ISASourceSchema]] = None
    samples: Optional[List[sample_schema.ISASampleSchema]] = None
    otherMaterials: Optional[List[material_schema.ISAMaterialSchema]] = None



# generated by datamodel-codegen:
#   filename:  publication_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import comment_schema, ontology_annotation_schema


class FieldType(Enum):
    Publication = 'Publication'


class ISAPublicationSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    pubMedID: Optional[str] = None
    doi: Optional[str] = None
    authorList: Optional[str] = None
    title: Optional[str] = None
    status: Optional[ontology_annotation_schema.ISAOntologyReferenceSchema] = None
    comments: Optional[List[comment_schema.ISACommentSchema]] = None



# generated by datamodel-codegen:
#   filename:  source_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import comment_schema, material_attribute_value_schema


class FieldType(Enum):
    Source = 'Source'


class IsaSourceSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    name: Optional[str] = None
    characteristics: Optional[List[
        material_attribute_value_schema.IsaMaterialAttributeSchema]] = None
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None



# generated by datamodel-codegen:
#   filename:  person_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, EmailStr, Extra, Field

from . import comment_schema, ontology_annotation_schema


class FieldType(Enum):
    Person = 'Person'


class ISAPersonSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    lastName: Optional[str] = None
    firstName: Optional[str] = None
    midInitials: Optional[str] = None
    email: Optional[EmailStr] = None
    phone: Optional[str] = None
    fax: Optional[str] = None
    address: Optional[str] = None
    affiliation: Optional[str] = None
    roles: Optional[List[ontology_annotation_schema.ISAOntologyReferenceSchema]] = None
    comments: Optional[List[comment_schema.ISACommentSchema]] = None



# generated by datamodel-codegen:
#   filename:  protocol_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import comment_schema, ontology_annotation_schema, protocol_parameter_schema


class Component(BaseModel):
    componentName: Optional[str] = None
    componentType: Optional[ontology_annotation_schema.ISAOntologyReferenceSchema] = (None)
    comments: Optional[List[comment_schema.ISACommentSchema]] = None


class FieldType(Enum):
    Protocol = 'Protocol'


class ISAProtocolSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    name: Optional[str] = None
    protocolType: Optional[ontology_annotation_schema.ISAOntologyReferenceSchema] = None
    description: Optional[str] = None
    uri: Optional[str] = None
    version: Optional[str] = None
    parameters: Optional[List[protocol_parameter_schema.ISAProtocolParameterSchema]] = (None)
    components: Optional[List[Component]] = None
    comments: Optional[List[comment_schema.ISACommentSchema]] = None



# generated by datamodel-codegen:
#   filename:  study_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from datetime import date, datetime
from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, constr, Extra, Field

from . import (assay_schema,
               comment_schema,
               factor_schema,
               material_attribute_schema,
               material_schema,
               ontology_annotation_schema,
               person_schema,
               process_schema,
               protocol_schema,
               publication_schema,
               sample_schema,
               source_schema)


class FieldType(Enum):
    Study = 'Study'


class IsaStudyJsonSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    filename: Optional[str] = None
    identifier: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None
    submissionDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    publicReleaseDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    publications: Optional[List[publication_schema.IsaPublicationSchema]] = None
    people: Optional[List[person_schema.IsaPersonSchema]] = None
    studyDesignDescriptors: Optional[List[
        ontology_annotation_schema.IsaOntologyReferenceSchema]] = None
    protocols: Optional[List[protocol_schema.IsaProtocolSchema]] = None
    materials: Optional[Materials] = None
    processSequence: Optional[List[
        process_schema.
        IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles]] = None
    assays: Optional[List[assay_schema.IsaAssayJsonSchema]] = None
    factors: Optional[List[factor_schema.IsaFactorSchema]] = None
    characteristicCategories: Optional[List[
        material_attribute_schema.IsaMaterialAttributeSchema]] = Field(
            None,
            description=
            'List of all the characteristics categories (or material attributes) defined in the study, used to avoid duplication of their declaration when each material_attribute_value is created. ',
        )
    unitCategories: Optional[List[ontology_annotation_schema.IsaOntologyReferenceSchema]] = Field(
        None,
        description=
        'List of all the units defined in the study, used to avoid duplication of their declaration when each value is created. ',
    )
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None


class Materials(BaseModel):
    sources: Optional[List[source_schema.IsaSourceSchema]] = None
    samples: Optional[List[sample_schema.IsaSampleSchema]] = None
    otherMaterials: Optional[List[material_schema.IsaMaterialSchema]] = None



# generated by datamodel-codegen:
#   filename:  ontology_source_reference_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import comment_schema


class FieldType(Enum):
    OntologySourceReference = 'OntologySourceReference'


class IsaOntologySourceReferenceSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None
    description: Optional[str] = None
    file: Optional[str] = None
    name: Optional[str] = None
    version: Optional[str] = None



# generated by datamodel-codegen:
#   filename:  assay_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import (comment_schema,
               data_schema,
               material_attribute_schema,
               material_schema,
               ontology_annotation_schema,
               process_schema,
               sample_schema)


class FieldType(Enum):
    Assay = 'Assay'


class IsaAssayJsonSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    filename: Optional[str] = None
    measurementType: Optional[ontology_annotation_schema.IsaOntologyReferenceSchema] = (None)
    technologyType: Optional[ontology_annotation_schema.IsaOntologyReferenceSchema] = (None)
    technologyPlatform: Optional[str] = None
    dataFiles: Optional[List[data_schema.IsaDataSchema]] = None
    materials: Optional[Materials] = None
    characteristicCategories: Optional[List[
        material_attribute_schema.IsaMaterialAttributeSchema]] = Field(
            None,
            description=
            'List of all the characteristics categories (or material attributes) defined in the study, used to avoid duplication of their declaration when each material_attribute_value is created. ',
        )
    unitCategories: Optional[List[ontology_annotation_schema.IsaOntologyReferenceSchema]] = Field(
        None,
        description=
        'List of all the unitsdefined in the study, used to avoid duplication of their declaration when each value is created. ',
    )
    processSequence: Optional[List[
        process_schema.
        IsaProcessOrProtocolApplicationSchemaCorrespondsToProtocolRefColumnsInTheStudyAndAssayFiles]] = None
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None


class Materials(BaseModel):
    samples: Optional[List[sample_schema.IsaSampleSchema]] = None
    otherMaterials: Optional[List[material_schema.IsaMaterialSchema]] = None



# generated by datamodel-codegen:
#   filename:  investigation_schema.json
#   timestamp: 2024-02-07T08:08:38+00:00

from __future__ import annotations

from datetime import date, datetime
from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, constr, Extra, Field

from . import (comment_schema,
               ontology_source_reference_schema,
               person_schema,
               publication_schema,
               study_schema)


class FieldType(Enum):
    Investigation = 'Investigation'


class IsaInvestigationSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    filename: Optional[str] = None
    identifier: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None
    submissionDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    publicReleaseDate: Optional[Union[datetime, date, constr(max_length=0)]] = None
    ontologySourceReferences: Optional[List[
        ontology_source_reference_schema.IsaOntologySourceReferenceSchema]] = None
    publications: Optional[List[publication_schema.IsaPublicationSchema]] = None
    people: Optional[List[person_schema.IsaPersonSchema]] = None
    studies: Optional[List[study_schema.IsaStudyJsonSchema]] = None
    comments: Optional[List[
        comment_schema.IsaCommentSchemaItCorrespondsToIsaCommentConstruct]] = None



from omnipy import runtime
from omnipy_examples.main import chatgpt, dagsim, encode, gff, isajson, uniprot
from prefect import flow as prefect_flow

runtime.config.engine = 'prefect'
runtime.config.data.interactive_mode = False


@prefect_flow
def dagsim_prefect():
    dagsim()


@prefect_flow
def encode_prefect():
    encode()


@prefect_flow
def gff_prefect():
    gff()


@prefect_flow
def isajson_prefect():
    isajson()


@prefect_flow
def uniprot_prefect():
    uniprot()


@prefect_flow
def chatgpt_prefect():
    chatgpt()


# isajson_prefect.deploy(
#     'isajson', work_pool_name='kubernetes-agent', image='fairtracks/omnipy-examples:latest')
#
# if __name__ == "__main__":
#     isajson_prefect.serve(name="isajson-prefect-deployment")



# generated by datamodel-codegen:
#   filename:  material_attribute_value_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, Extra, Field

from . import comment_schema, material_attribute_schema, ontology_annotation_schema


class FieldType(Enum):
    MaterialAttributeValue = 'MaterialAttributeValue'


class ISAMaterialAttributeSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    category: Optional[material_attribute_schema.ISAMaterialAttributeSchema] = None
    value: Optional[Union[ontology_annotation_schema.ISAOntologyReferenceSchema, str, float]] = None
    unit: Optional[ontology_annotation_schema.ISAOntologyReferenceSchema] = None
    comments: Optional[List[comment_schema.ISACommentSchema]] = None
